Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1DataplexExternalTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

External table registered by Dataplex Universal Catalog. Dataplex Universal Catalog publishes data discovered from an asset into multiple other systems ( BigQuery, DPMS) in form of tables. We call them "external tables". External tables are also synced into the Data Catalog. This message contains pointers to those external tables (fully qualified name, resource name et cetera) within the Data Catalog.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1DataplexExternalTable

Returns a new instance of GoogleCloudDatacatalogV1DataplexExternalTable.



862
863
864
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_catalog_entryString

Name of the Data Catalog entry representing the external table. Corresponds to the JSON property dataCatalogEntry

Returns:

  • (String)


845
846
847
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 845

def data_catalog_entry
  @data_catalog_entry
end

#fully_qualified_nameString

Fully qualified name (FQN) of the external table. Corresponds to the JSON property fullyQualifiedName

Returns:

  • (String)


850
851
852
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 850

def fully_qualified_name
  @fully_qualified_name
end

#google_cloud_resourceString

Google Cloud resource name of the external table. Corresponds to the JSON property googleCloudResource

Returns:

  • (String)


855
856
857
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 855

def google_cloud_resource
  @google_cloud_resource
end

#systemString

Service in which the external table is registered. Corresponds to the JSON property system

Returns:

  • (String)


860
861
862
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 860

def system
  @system
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



867
868
869
870
871
872
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 867

def update!(**args)
  @data_catalog_entry = args[:data_catalog_entry] if args.key?(:data_catalog_entry)
  @fully_qualified_name = args[:fully_qualified_name] if args.key?(:fully_qualified_name)
  @google_cloud_resource = args[:google_cloud_resource] if args.key?(:google_cloud_resource)
  @system = args[:system] if args.key?(:system)
end