Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1DataplexTableSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

Entry specification for a Dataplex Universal Catalog table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1DataplexTableSpec

Returns a new instance of GoogleCloudDatacatalogV1DataplexTableSpec.



958
959
960
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataplex_specGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1DataplexSpec

Common Dataplex Universal Catalog fields. Corresponds to the JSON property dataplexSpec



943
944
945
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 943

def dataplex_spec
  @dataplex_spec
end

#external_tablesArray<Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1DataplexExternalTable>

List of external tables registered by Dataplex Universal Catalog in other systems based on the same underlying data. External tables allow to query this data in those systems. Corresponds to the JSON property externalTables



950
951
952
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 950

def external_tables
  @external_tables
end

#user_managedBoolean Also known as: user_managed?

Indicates if the table schema is managed by the user or not. Corresponds to the JSON property userManaged

Returns:

  • (Boolean)


955
956
957
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 955

def user_managed
  @user_managed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



963
964
965
966
967
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 963

def update!(**args)
  @dataplex_spec = args[:dataplex_spec] if args.key?(:dataplex_spec)
  @external_tables = args[:external_tables] if args.key?(:external_tables)
  @user_managed = args[:user_managed] if args.key?(:user_managed)
end