Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1EntryGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

Entry group metadata. An EntryGroup resource represents a logical grouping of zero or more Data Catalog Entry resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1EntryGroup

Returns a new instance of GoogleCloudDatacatalogV1EntryGroup.



1307
1308
1309
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1307

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_catalog_timestampsGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SystemTimestamps

Timestamps associated with this resource in a particular system. Corresponds to the JSON property dataCatalogTimestamps



1277
1278
1279
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1277

def data_catalog_timestamps
  @data_catalog_timestamps
end

#descriptionString

Entry group description. Can consist of several sentences or paragraphs that describe the entry group contents. Default value is an empty string. Corresponds to the JSON property description

Returns:

  • (String)


1283
1284
1285
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1283

def description
  @description
end

#display_nameString

A short name to identify the entry group, for example, "analytics data - jan 2011". Default value is an empty string. Corresponds to the JSON property displayName

Returns:

  • (String)


1289
1290
1291
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1289

def display_name
  @display_name
end

#nameString

Identifier. The resource name of the entry group in URL format. Note: The entry group itself and its child resources might not be stored in the location specified in its name. Corresponds to the JSON property name

Returns:

  • (String)


1296
1297
1298
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1296

def name
  @name
end

#transferred_to_dataplexBoolean Also known as: transferred_to_dataplex?

Optional. When set to [true], it means DataCatalog EntryGroup was transferred to Dataplex Universal Catalog. It makes EntryGroup and its Entries to be read- only in DataCatalog. However, new Tags on EntryGroup and its Entries can be created. After setting the flag to [true] it cannot be unset. Corresponds to the JSON property transferredToDataplex

Returns:

  • (Boolean)


1304
1305
1306
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1304

def transferred_to_dataplex
  @transferred_to_dataplex
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1312
1313
1314
1315
1316
1317
1318
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1312

def update!(**args)
  @data_catalog_timestamps = args[:data_catalog_timestamps] if args.key?(:data_catalog_timestamps)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @transferred_to_dataplex = args[:transferred_to_dataplex] if args.key?(:transferred_to_dataplex)
end