Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1EntryOverview
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1EntryOverview
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
Entry overview fields for rich text descriptions of entries.
Instance Attribute Summary collapse
-
#overview ⇒ String
Entry overview with support for rich text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1EntryOverview
constructor
A new instance of GoogleCloudDatacatalogV1EntryOverview.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1EntryOverview
Returns a new instance of GoogleCloudDatacatalogV1EntryOverview.
1333 1334 1335 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#overview ⇒ String
Entry overview with support for rich text. The overview must only contain
Unicode characters, and should be formatted using HTML. The maximum length is
10 MiB as this value holds HTML descriptions including encoded images. The
maximum length of the text without images is 100 KiB.
Corresponds to the JSON property overview
1331 1332 1333 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1331 def overview @overview end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1338 1339 1340 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1338 def update!(**args) @overview = args[:overview] if args.key?(:overview) end |