Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GcsFilesetSpec
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GcsFilesetSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
Describes a Cloud Storage fileset entry.
Instance Attribute Summary collapse
-
#file_patterns ⇒ Array<String>
Required.
-
#sample_gcs_file_specs ⇒ Array<Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GcsFileSpec>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1GcsFilesetSpec
constructor
A new instance of GoogleCloudDatacatalogV1GcsFilesetSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1GcsFilesetSpec
Returns a new instance of GoogleCloudDatacatalogV1GcsFilesetSpec.
1532 1533 1534 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_patterns ⇒ Array<String>
Required. Patterns to identify a set of files in Google Cloud Storage. For
more information, see Wildcard Names. Note: Currently, bucket wildcards are not supported. Examples of
valid file_patterns: * gs://bucket_name/dir/*: matches all files in
bucket_name/dir directory * gs://bucket_name/dir/**: matches all files in
bucket_name/dir and all subdirectories * gs://bucket_name/file*: matches
files prefixed by file in bucket_name * gs://bucket_name/??.txt: matches
files with two characters followed by .txt in bucket_name * gs://
bucket_name/[aeiou].txt: matches files that contain a single vowel character
followed by .txt in bucket_name * gs://bucket_name/[a-m].txt: matches
files that contain a, b, ... or m followed by .txt in bucket_name *
gs://bucket_name/a/*/b: matches all files in bucket_name that match the a/*
/b pattern, such as a/c/b, a/d/b * gs://another_bucket/a.txt: matches
gs://another_bucket/a.txt You can combine wildcards to match complex sets of
files, for example: gs://bucket_name/[a-m]??.j*g
Corresponds to the JSON property filePatterns
1524 1525 1526 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1524 def file_patterns @file_patterns end |
#sample_gcs_file_specs ⇒ Array<Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GcsFileSpec>
Output only. Sample files contained in this fileset, not all files contained
in this fileset are represented here.
Corresponds to the JSON property sampleGcsFileSpecs
1530 1531 1532 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1530 def sample_gcs_file_specs @sample_gcs_file_specs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1537 1538 1539 1540 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1537 def update!(**args) @file_patterns = args[:file_patterns] if args.key?(:file_patterns) @sample_gcs_file_specs = args[:sample_gcs_file_specs] if args.key?(:sample_gcs_file_specs) end |