Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GraphSpecGraphElementTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

Element table definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1GraphSpecGraphElementTable

Returns a new instance of GoogleCloudDatacatalogV1GraphSpecGraphElementTable.



1632
1633
1634
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aliasString

Required. The alias name of the graph element. Corresponds to the JSON property alias

Returns:

  • (String)


1581
1582
1583
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1581

def alias
  @alias
end

#data_sourceString

Required. The name of the data source. This is either a table name or a view name that is used for graph element input source. E.g. Person table or PersonView view. Corresponds to the JSON property dataSource

Returns:

  • (String)


1588
1589
1590
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1588

def data_source
  @data_source
end

#destination_node_referenceGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference

A reference to a source or destination node in a graph edge. Corresponds to the JSON property destinationNodeReference



1593
1594
1595
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1593

def destination_node_reference
  @destination_node_reference
end

#dynamic_label_columnString

Optional. If set, this is the input column for dynamic label in schemaless data model. Corresponds to the JSON property dynamicLabelColumn

Returns:

  • (String)


1599
1600
1601
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1599

def dynamic_label_column
  @dynamic_label_column
end

#dynamic_properties_columnString

Optional. If set, this is the input column for dynamic properties in schemaless data model. Corresponds to the JSON property dynamicPropertiesColumn

Returns:

  • (String)


1605
1606
1607
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1605

def dynamic_properties_column
  @dynamic_properties_column
end

#element_keysArray<String>

Required. The name of the keys of the elements in the table. Corresponds to the JSON property elementKeys

Returns:

  • (Array<String>)


1610
1611
1612
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1610

def element_keys
  @element_keys
end

#input_sourceString

Required. The input source of the graph element. Corresponds to the JSON property inputSource

Returns:

  • (String)


1615
1616
1617
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1615

def input_source
  @input_source
end

#kindString

Required. The kind of the graph element. Corresponds to the JSON property kind

Returns:

  • (String)


1620
1621
1622
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1620

def kind
  @kind
end

#label_and_propertiesArray<Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableLabelAndProperties>

Required. The labels and their properties for the graph element. Corresponds to the JSON property labelAndProperties



1625
1626
1627
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1625

def label_and_properties
  @label_and_properties
end

#source_node_referenceGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference

A reference to a source or destination node in a graph edge. Corresponds to the JSON property sourceNodeReference



1630
1631
1632
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1630

def source_node_reference
  @source_node_reference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1637

def update!(**args)
  @alias = args[:alias] if args.key?(:alias)
  @data_source = args[:data_source] if args.key?(:data_source)
  @destination_node_reference = args[:destination_node_reference] if args.key?(:destination_node_reference)
  @dynamic_label_column = args[:dynamic_label_column] if args.key?(:dynamic_label_column)
  @dynamic_properties_column = args[:dynamic_properties_column] if args.key?(:dynamic_properties_column)
  @element_keys = args[:element_keys] if args.key?(:element_keys)
  @input_source = args[:input_source] if args.key?(:input_source)
  @kind = args[:kind] if args.key?(:kind)
  @label_and_properties = args[:label_and_properties] if args.key?(:label_and_properties)
  @source_node_reference = args[:source_node_reference] if args.key?(:source_node_reference)
end