Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1ImportEntriesMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

Metadata message for long-running operation returned by the ImportEntries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1ImportEntriesMetadata

Returns a new instance of GoogleCloudDatacatalogV1ImportEntriesMetadata.



1752
1753
1754
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::DatacatalogV1::Status>

Partial errors that are encountered during the ImportEntries operation. There is no guarantee that all the encountered errors are reported. However, if no errors are reported, it means that no errors were encountered. Corresponds to the JSON property errors



1745
1746
1747
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1745

def errors
  @errors
end

#stateString

State of the import operation. Corresponds to the JSON property state

Returns:

  • (String)


1750
1751
1752
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1750

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1757
1758
1759
1760
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1757

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
  @state = args[:state] if args.key?(:state)
end