Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1ImportEntriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

Request message for ImportEntries method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1ImportEntriesRequest

Returns a new instance of GoogleCloudDatacatalogV1ImportEntriesRequest.



1778
1779
1780
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_bucket_pathString

Path to a Cloud Storage bucket that contains a dump ready for ingestion. Corresponds to the JSON property gcsBucketPath

Returns:

  • (String)


1770
1771
1772
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1770

def gcs_bucket_path
  @gcs_bucket_path
end

#job_idString

Optional. (Optional) Dataplex Universal Catalog task job id, if specified will be used as part of ImportEntries LRO ID Corresponds to the JSON property jobId

Returns:

  • (String)


1776
1777
1778
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1776

def job_id
  @job_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1783
1784
1785
1786
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1783

def update!(**args)
  @gcs_bucket_path = args[:gcs_bucket_path] if args.key?(:gcs_bucket_path)
  @job_id = args[:job_id] if args.key?(:job_id)
end