Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PersonalDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

Entry metadata relevant only to the user and private to them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1PersonalDetails

Returns a new instance of GoogleCloudDatacatalogV1PersonalDetails.



2190
2191
2192
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#star_timeString

Set if the entry is starred; unset otherwise. Corresponds to the JSON property starTime

Returns:

  • (String)


2182
2183
2184
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2182

def star_time
  @star_time
end

#starredBoolean Also known as: starred?

True if the entry is starred by the user; false otherwise. Corresponds to the JSON property starred

Returns:

  • (Boolean)


2187
2188
2189
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2187

def starred
  @starred
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2195
2196
2197
2198
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2195

def update!(**args)
  @star_time = args[:star_time] if args.key?(:star_time)
  @starred = args[:starred] if args.key?(:starred)
end