Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PhysicalSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

Native schema used by a resource represented as an entry. Used by query engines for deserializing and parsing source data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1PhysicalSchema

Returns a new instance of GoogleCloudDatacatalogV1PhysicalSchema.



2236
2237
2238
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avroGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PhysicalSchemaAvroSchema

Schema in Avro JSON format. Corresponds to the JSON property avro



2209
2210
2211
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2209

def avro
  @avro
end

#csvGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PhysicalSchemaCsvSchema

Marks a CSV-encoded data source. Corresponds to the JSON property csv



2214
2215
2216
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2214

def csv
  @csv
end

#orcGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PhysicalSchemaOrcSchema

Marks an ORC-encoded data source. Corresponds to the JSON property orc



2219
2220
2221
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2219

def orc
  @orc
end

#parquetGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PhysicalSchemaParquetSchema

Marks a Parquet-encoded data source. Corresponds to the JSON property parquet



2224
2225
2226
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2224

def parquet
  @parquet
end

#protobufGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PhysicalSchemaProtobufSchema

Schema in protocol buffer format. Corresponds to the JSON property protobuf



2229
2230
2231
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2229

def protobuf
  @protobuf
end

#thriftGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PhysicalSchemaThriftSchema

Schema in Thrift format. Corresponds to the JSON property thrift



2234
2235
2236
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2234

def thrift
  @thrift
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2241
2242
2243
2244
2245
2246
2247
2248
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2241

def update!(**args)
  @avro = args[:avro] if args.key?(:avro)
  @csv = args[:csv] if args.key?(:csv)
  @orc = args[:orc] if args.key?(:orc)
  @parquet = args[:parquet] if args.key?(:parquet)
  @protobuf = args[:protobuf] if args.key?(:protobuf)
  @thrift = args[:thrift] if args.key?(:thrift)
end