Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
Request message for SearchCatalog.
Instance Attribute Summary collapse
-
#admin_search ⇒ Boolean
(also: #admin_search?)
Optional.
-
#order_by ⇒ String
Specifies the order of results.
-
#page_size ⇒ Fixnum
Upper bound on the number of results you can get in a single response.
-
#page_token ⇒ String
Optional.
-
#query ⇒ String
Optional.
-
#scope ⇒ Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogRequestScope
The criteria that select the subspace used for query matching.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SearchCatalogRequest
constructor
A new instance of GoogleCloudDatacatalogV1SearchCatalogRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SearchCatalogRequest
Returns a new instance of GoogleCloudDatacatalogV1SearchCatalogRequest.
2714 2715 2716 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_search ⇒ Boolean Also known as: admin_search?
Optional. If set, use searchAll permission granted on organizations from
include_org_ids and projects from include_project_ids instead of the fine
grained per resource permissions when filtering the search results. The only
allowed order_by criteria for admin_search mode is default. Using this
flags guarantees a full recall of the search results.
Corresponds to the JSON property adminSearch
2668 2669 2670 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2668 def admin_search @admin_search end |
#order_by ⇒ String
Specifies the order of results. Currently supported case-sensitive values are:
relevancethat can only be descending *last_modified_timestamp [asc|desc]with descending (desc) as default *defaultthat can only be descending Search queries don't guarantee full recall. Results that match your query might not be returned, even in subsequent result pages. Additionally, returned (and not returned) results can vary if you repeat search queries. If you are experiencing recall issues and you don't have to fetch the results in any specific order, consider setting this parameter todefault. If this parameter is omitted, it defaults to the descendingrelevance. Corresponds to the JSON propertyorderBy
2682 2683 2684 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2682 def order_by @order_by end |
#page_size ⇒ Fixnum
Upper bound on the number of results you can get in a single response. Can't
be negative or 0, defaults to 10 in this case. The maximum number is 1000. If
exceeded, throws an "invalid argument" exception.
Corresponds to the JSON property pageSize
2689 2690 2691 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2689 def page_size @page_size end |
#page_token ⇒ String
Optional. Pagination token that, if specified, returns the next page of search
results. If empty, returns the first page. This token is returned in the
SearchCatalogResponse.next_page_token field of the response to a previous
SearchCatalogRequest call.
Corresponds to the JSON property pageToken
2697 2698 2699 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2697 def page_token @page_token end |
#query ⇒ String
Optional. The query string with a minimum of 3 characters and specific syntax.
For more information, see Data Catalog search syntax. An empty query string returns
all data assets (in the specified scope) that you have access to. A query
string can be a simple xyz or qualified by predicates: * name:x * column:
y * description:z
Corresponds to the JSON property query
2707 2708 2709 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2707 def query @query end |
#scope ⇒ Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogRequestScope
The criteria that select the subspace used for query matching.
Corresponds to the JSON property scope
2712 2713 2714 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2712 def scope @scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2719 def update!(**args) @admin_search = args[:admin_search] if args.key?(:admin_search) @order_by = args[:order_by] if args.key?(:order_by) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @query = args[:query] if args.key?(:query) @scope = args[:scope] if args.key?(:scope) end |