Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogRequestScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

The criteria that select the subspace used for query matching.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1SearchCatalogRequestScope

Returns a new instance of GoogleCloudDatacatalogV1SearchCatalogRequestScope.



2780
2781
2782
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_gcp_public_datasetsBoolean Also known as: include_gcp_public_datasets?

If true, include Google Cloud public datasets in search results. By default, they are excluded. See Google Cloud Public Datasets for more information. Corresponds to the JSON property includeGcpPublicDatasets

Returns:

  • (Boolean)


2738
2739
2740
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2738

def include_gcp_public_datasets
  @include_gcp_public_datasets
end

#include_org_idsArray<String>

The list of organization IDs to search within. To find your organization ID, follow the steps from Creating and managing organizations. Corresponds to the JSON property includeOrgIds

Returns:

  • (Array<String>)


2746
2747
2748
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2746

def include_org_ids
  @include_org_ids
end

#include_project_idsArray<String>

The list of project IDs to search within. For more information on the distinction between project names, IDs, and numbers, see Projects. Corresponds to the JSON property includeProjectIds

Returns:

  • (Array<String>)


2753
2754
2755
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2753

def include_project_ids
  @include_project_ids
end

#include_public_tag_templatesBoolean Also known as: include_public_tag_templates?

Optional. This field is deprecated. The search mechanism for public and private tag templates is the same. Corresponds to the JSON property includePublicTagTemplates

Returns:

  • (Boolean)


2759
2760
2761
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2759

def include_public_tag_templates
  @include_public_tag_templates
end

#restricted_locationsArray<String>

Optional. The list of locations to search within. If empty, all locations are searched. Returns an error if any location in the list isn't one of the Supported regions. If a location is unreachable, its name is returned in the SearchCatalogResponse.unreachable field. To get additional information on the error, repeat the search request and set the location name as the value of this parameter. Corresponds to the JSON property restrictedLocations

Returns:

  • (Array<String>)


2771
2772
2773
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2771

def restricted_locations
  @restricted_locations
end

#starred_onlyBoolean Also known as: starred_only?

Optional. If true, search only among starred entries. By default, all results are returned, starred or not. Corresponds to the JSON property starredOnly

Returns:

  • (Boolean)


2777
2778
2779
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2777

def starred_only
  @starred_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2785

def update!(**args)
  @include_gcp_public_datasets = args[:include_gcp_public_datasets] if args.key?(:include_gcp_public_datasets)
  @include_org_ids = args[:include_org_ids] if args.key?(:include_org_ids)
  @include_project_ids = args[:include_project_ids] if args.key?(:include_project_ids)
  @include_public_tag_templates = args[:include_public_tag_templates] if args.key?(:include_public_tag_templates)
  @restricted_locations = args[:restricted_locations] if args.key?(:restricted_locations)
  @starred_only = args[:starred_only] if args.key?(:starred_only)
end