Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogResult
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
Result in the response to a search request. Each result captures details of one entry that matches the search.
Instance Attribute Summary collapse
-
#description ⇒ String
Entry description that can consist of several sentences or paragraphs that describe entry contents.
-
#display_name ⇒ String
The display name of the result.
-
#fully_qualified_name ⇒ String
Fully qualified name (FQN) of the resource.
-
#integrated_system ⇒ String
Output only.
-
#linked_resource ⇒ String
The full name of the Google Cloud resource the entry belongs to.
-
#modify_time ⇒ String
The last modification timestamp of the entry in the source system.
-
#relative_resource_name ⇒ String
The relative name of the resource in URL format.
-
#search_result_subtype ⇒ String
Sub-type of the search result.
-
#search_result_type ⇒ String
Type of the search result.
-
#user_specified_system ⇒ String
Custom source system that you can manually integrate Data Catalog with.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SearchCatalogResult
constructor
A new instance of GoogleCloudDatacatalogV1SearchCatalogResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SearchCatalogResult
Returns a new instance of GoogleCloudDatacatalogV1SearchCatalogResult.
2906 2907 2908 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Entry description that can consist of several sentences or paragraphs that
describe entry contents.
Corresponds to the JSON property description
2845 2846 2847 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2845 def description @description end |
#display_name ⇒ String
The display name of the result.
Corresponds to the JSON property displayName
2850 2851 2852 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2850 def display_name @display_name end |
#fully_qualified_name ⇒ String
Fully qualified name (FQN) of the resource. FQNs take two forms: * For non-
regionalized resources: SYSTEM`:`PROJECT`.`
PATH_TO_RESOURCE_SEPARATED_WITH_DOTS * For regionalized resources: SYSTEM`:
`PROJECT`.`LOCATION_ID`.`PATH_TO_RESOURCE_SEPARATED_WITH_DOTS Example for a
DPMS table: dataproc_metastore:PROJECT_ID.LOCATION_ID.INSTANCE_ID.DATABASE_ID.
TABLE_ID
Corresponds to the JSON property fullyQualifiedName
2860 2861 2862 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2860 def fully_qualified_name @fully_qualified_name end |
#integrated_system ⇒ String
Output only. The source system that Data Catalog automatically integrates with,
such as BigQuery, Cloud Pub/Sub, or Dataproc Metastore.
Corresponds to the JSON property integratedSystem
2866 2867 2868 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2866 def integrated_system @integrated_system end |
#linked_resource ⇒ String
The full name of the Google Cloud resource the entry belongs to. For more
information, see Full Resource Name. Example: //bigquery.googleapis.com/projects/PROJECT_ID/
datasets/DATASET_ID/tables/TABLE_ID
Corresponds to the JSON property linkedResource
2874 2875 2876 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2874 def linked_resource @linked_resource end |
#modify_time ⇒ String
The last modification timestamp of the entry in the source system.
Corresponds to the JSON property modifyTime
2879 2880 2881 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2879 def modify_time @modify_time end |
#relative_resource_name ⇒ String
The relative name of the resource in URL format. Examples: * projects/
PROJECT_ID/locations/LOCATION_ID/entryGroups/ENTRY_GROUP_ID/entries/
ENTRY_ID* `projects/`PROJECT_ID`/tagTemplates/`TAG_TEMPLATE_ID
Corresponds to the JSON property relativeResourceName
2886 2887 2888 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2886 def relative_resource_name @relative_resource_name end |
#search_result_subtype ⇒ String
Sub-type of the search result. A dot-delimited full type of the resource. The
same type you specify in the type search predicate. Examples: entry.table,
entry.dataStream, tagTemplate.
Corresponds to the JSON property searchResultSubtype
2893 2894 2895 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2893 def search_result_subtype @search_result_subtype end |
#search_result_type ⇒ String
Type of the search result. You can use this field to determine which get
method to call to fetch the full resource.
Corresponds to the JSON property searchResultType
2899 2900 2901 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2899 def search_result_type @search_result_type end |
#user_specified_system ⇒ String
Custom source system that you can manually integrate Data Catalog with.
Corresponds to the JSON property userSpecifiedSystem
2904 2905 2906 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2904 def user_specified_system @user_specified_system end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2911 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @fully_qualified_name = args[:fully_qualified_name] if args.key?(:fully_qualified_name) @integrated_system = args[:integrated_system] if args.key?(:integrated_system) @linked_resource = args[:linked_resource] if args.key?(:linked_resource) @modify_time = args[:modify_time] if args.key?(:modify_time) @relative_resource_name = args[:relative_resource_name] if args.key?(:relative_resource_name) @search_result_subtype = args[:search_result_subtype] if args.key?(:search_result_subtype) @search_result_type = args[:search_result_type] if args.key?(:search_result_type) @user_specified_system = args[:user_specified_system] if args.key?(:user_specified_system) end |