Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SetConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SetConfigRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
Request message for SetConfig.
Instance Attribute Summary collapse
-
#catalog_ui_experience ⇒ String
Opt-in status for the UI switch to Dataplex Universal Catalog.
-
#tag_template_migration ⇒ String
Opt-in status for the migration of Tag Templates to Dataplex Universal Catalog.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SetConfigRequest
constructor
A new instance of GoogleCloudDatacatalogV1SetConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SetConfigRequest
Returns a new instance of GoogleCloudDatacatalogV1SetConfigRequest.
3040 3041 3042 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog_ui_experience ⇒ String
Opt-in status for the UI switch to Dataplex Universal Catalog.
Corresponds to the JSON property catalogUiExperience
3033 3034 3035 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3033 def catalog_ui_experience @catalog_ui_experience end |
#tag_template_migration ⇒ String
Opt-in status for the migration of Tag Templates to Dataplex Universal Catalog.
Corresponds to the JSON property tagTemplateMigration
3038 3039 3040 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3038 def tag_template_migration @tag_template_migration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3045 3046 3047 3048 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3045 def update!(**args) @catalog_ui_experience = args[:catalog_ui_experience] if args.key?(:catalog_ui_experience) @tag_template_migration = args[:tag_template_migration] if args.key?(:tag_template_migration) end |