Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SpannerTableSpecSpannerForeignKeyForeignKeyColumnMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

Column mapping for a Spanner foreign key.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1SpannerTableSpecSpannerForeignKeyForeignKeyColumnMapping

Returns a new instance of GoogleCloudDatacatalogV1SpannerTableSpecSpannerForeignKeyForeignKeyColumnMapping.



3125
3126
3127
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

Output only. The column in the current table that is part of the foreign key. Corresponds to the JSON property column

Returns:

  • (String)


3117
3118
3119
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3117

def column
  @column
end

#reference_columnString

Output only. The column in the referenced table that is part of the foreign key. Corresponds to the JSON property referenceColumn

Returns:

  • (String)


3123
3124
3125
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3123

def reference_column
  @reference_column
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3130
3131
3132
3133
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3130

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @reference_column = args[:reference_column] if args.key?(:reference_column)
end