Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SystemTimestamps
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SystemTimestamps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
Timestamps associated with this resource in a particular system.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Creation timestamp of the resource within the given system.
-
#expire_time ⇒ String
Output only.
-
#update_time ⇒ String
Timestamp of the last modification of the resource or its metadata within a given system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SystemTimestamps
constructor
A new instance of GoogleCloudDatacatalogV1SystemTimestamps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SystemTimestamps
Returns a new instance of GoogleCloudDatacatalogV1SystemTimestamps.
3275 3276 3277 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Creation timestamp of the resource within the given system.
Corresponds to the JSON property createTime
3259 3260 3261 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3259 def create_time @create_time end |
#expire_time ⇒ String
Output only. Expiration timestamp of the resource within the given system.
Currently only applicable to BigQuery resources.
Corresponds to the JSON property expireTime
3265 3266 3267 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3265 def expire_time @expire_time end |
#update_time ⇒ String
Timestamp of the last modification of the resource or its metadata within a
given system. Note: Depending on the source system, not every modification
updates this timestamp. For example, BigQuery timestamps every metadata
modification but not data or permission changes.
Corresponds to the JSON property updateTime
3273 3274 3275 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3273 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3280 3281 3282 3283 3284 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3280 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @expire_time = args[:expire_time] if args.key?(:expire_time) @update_time = args[:update_time] if args.key?(:update_time) end |