Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1Taxonomy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

A taxonomy is a collection of hierarchical policy tags that classify data along a common axis. For example, a "data sensitivity" taxonomy might contain the following policy tags: + PII + Account number + Age + SSN + Zipcode + Financials + Revenue A "data origin" taxonomy might contain the following policy tags: + User data + Employee data + Partner data + Public data

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1Taxonomy

Returns a new instance of GoogleCloudDatacatalogV1Taxonomy.



3672
3673
3674
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activated_policy_typesArray<String>

Optional. A list of policy types that are activated for this taxonomy. If not set, defaults to an empty list. Corresponds to the JSON property activatedPolicyTypes

Returns:

  • (Array<String>)


3634
3635
3636
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3634

def activated_policy_types
  @activated_policy_types
end

#descriptionString

Optional. Description of this taxonomy. If not set, defaults to empty. The description must contain only Unicode characters, tabs, newlines, carriage returns, and page breaks, and be at most 2000 bytes long when encoded in UTF-8. Corresponds to the JSON property description

Returns:

  • (String)


3641
3642
3643
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3641

def description
  @description
end

#display_nameString

Required. User-defined name of this taxonomy. The name can't start or end with spaces, must contain only Unicode letters, numbers, underscores, dashes, and spaces, and be at most 200 bytes long when encoded in UTF-8. The taxonomy display name must be unique within an organization. Corresponds to the JSON property displayName

Returns:

  • (String)


3649
3650
3651
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3649

def display_name
  @display_name
end

#nameString

Identifier. Resource name of this taxonomy in URL format. Note: Policy tag manager generates unique taxonomy IDs. Corresponds to the JSON property name

Returns:

  • (String)


3655
3656
3657
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3655

def name
  @name
end

#policy_tag_countFixnum

Output only. Number of policy tags in this taxonomy. Corresponds to the JSON property policyTagCount

Returns:

  • (Fixnum)


3660
3661
3662
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3660

def policy_tag_count
  @policy_tag_count
end

#serviceGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1TaxonomyService

The source system of the Taxonomy. Corresponds to the JSON property service



3665
3666
3667
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3665

def service
  @service
end

#taxonomy_timestampsGoogle::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SystemTimestamps

Timestamps associated with this resource in a particular system. Corresponds to the JSON property taxonomyTimestamps



3670
3671
3672
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3670

def taxonomy_timestamps
  @taxonomy_timestamps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3677
3678
3679
3680
3681
3682
3683
3684
3685
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3677

def update!(**args)
  @activated_policy_types = args[:activated_policy_types] if args.key?(:activated_policy_types)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @policy_tag_count = args[:policy_tag_count] if args.key?(:policy_tag_count)
  @service = args[:service] if args.key?(:service)
  @taxonomy_timestamps = args[:taxonomy_timestamps] if args.key?(:taxonomy_timestamps)
end