Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1UsageSignal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb

Overview

The set of all usage signals that Data Catalog stores. Note: Usually, these signals are updated daily. In rare cases, an update may fail but will be performed again on the next day.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1UsageSignal

Returns a new instance of GoogleCloudDatacatalogV1UsageSignal.



3767
3768
3769
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_usage_within_time_rangeHash<String,Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1CommonUsageStats>

Common usage statistics over each of the predefined time ranges. Supported time ranges are "24H", "7D", "30D", "Lifetime". Corresponds to the JSON property commonUsageWithinTimeRange



3749
3750
3751
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3749

def common_usage_within_time_range
  @common_usage_within_time_range
end

#favorite_countFixnum

Favorite count in the source system. Corresponds to the JSON property favoriteCount

Returns:

  • (Fixnum)


3754
3755
3756
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3754

def favorite_count
  @favorite_count
end

#update_timeString

The end timestamp of the duration of usage statistics. Corresponds to the JSON property updateTime

Returns:

  • (String)


3759
3760
3761
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3759

def update_time
  @update_time
end

#usage_within_time_rangeHash<String,Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1UsageStats>

Output only. BigQuery usage statistics over each of the predefined time ranges. Supported time ranges are "24H", "7D", "30D". Corresponds to the JSON property usageWithinTimeRange



3765
3766
3767
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3765

def usage_within_time_range
  @usage_within_time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3772
3773
3774
3775
3776
3777
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3772

def update!(**args)
  @common_usage_within_time_range = args[:common_usage_within_time_range] if args.key?(:common_usage_within_time_range)
  @favorite_count = args[:favorite_count] if args.key?(:favorite_count)
  @update_time = args[:update_time] if args.key?(:update_time)
  @usage_within_time_range = args[:usage_within_time_range] if args.key?(:usage_within_time_range)
end