Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1DataplexSpec
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1DataplexSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
Common Dataplex Universal Catalog fields.
Instance Attribute Summary collapse
-
#asset ⇒ String
Fully qualified resource name of an asset in Dataplex Universal Catalog, to which the underlying data source (Cloud Storage bucket or BigQuery dataset) of the entity is attached.
-
#compression_format ⇒ String
Compression format of the data, e.g., zip, gzip etc.
-
#data_format ⇒ Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PhysicalSchema
Native schema used by a resource represented as an entry.
-
#project_id ⇒ String
Project ID of the underlying Cloud Storage or BigQuery data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1DataplexSpec
constructor
A new instance of GoogleCloudDatacatalogV1DataplexSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1DataplexSpec
Returns a new instance of GoogleCloudDatacatalogV1DataplexSpec.
923 924 925 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 923 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
Fully qualified resource name of an asset in Dataplex Universal Catalog, to
which the underlying data source (Cloud Storage bucket or BigQuery dataset) of
the entity is attached.
Corresponds to the JSON property asset
903 904 905 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 903 def asset @asset end |
#compression_format ⇒ String
Compression format of the data, e.g., zip, gzip etc.
Corresponds to the JSON property compressionFormat
908 909 910 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 908 def compression_format @compression_format end |
#data_format ⇒ Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1PhysicalSchema
Native schema used by a resource represented as an entry. Used by query
engines for deserializing and parsing source data.
Corresponds to the JSON property dataFormat
914 915 916 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 914 def data_format @data_format end |
#project_id ⇒ String
Project ID of the underlying Cloud Storage or BigQuery data. Note that this
may not be the same project as the corresponding Dataplex Universal Catalog
lake / zone / asset.
Corresponds to the JSON property projectId
921 922 923 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 921 def project_id @project_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
928 929 930 931 932 933 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 928 def update!(**args) @asset = args[:asset] if args.key?(:asset) @compression_format = args[:compression_format] if args.key?(:compression_format) @data_format = args[:data_format] if args.key?(:data_format) @project_id = args[:project_id] if args.key?(:project_id) end |