Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
A reference to a source or destination node in a graph edge.
Instance Attribute Summary collapse
-
#edge_table_columns ⇒ Array<String>
Required.
-
#node_alias ⇒ String
Required.
-
#node_table_columns ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference
constructor
A new instance of GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference
Returns a new instance of GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference.
1673 1674 1675 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1673 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edge_table_columns ⇒ Array<String>
Required. The referencing columns in the edge table. The size of
edge_table_columns must be equal to the size of node_table_columns.
Corresponds to the JSON property edgeTableColumns
1659 1660 1661 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1659 def edge_table_columns @edge_table_columns end |
#node_alias ⇒ String
Required. The reference to the source/destination node of the edge. This name
must be a valid alias of a node element in the same graph. Example, Person
node can be a source node name of an edge element Person_to_Address.
Corresponds to the JSON property nodeAlias
1666 1667 1668 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1666 def node_alias @node_alias end |
#node_table_columns ⇒ Array<String>
Required. The referenced columns of the source node table.
Corresponds to the JSON property nodeTableColumns
1671 1672 1673 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1671 def node_table_columns @node_table_columns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1678 1679 1680 1681 1682 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 1678 def update!(**args) @edge_table_columns = args[:edge_table_columns] if args.key?(:edge_table_columns) @node_alias = args[:node_alias] if args.key?(:node_alias) @node_table_columns = args[:node_table_columns] if args.key?(:node_table_columns) end |