Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1MigrationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1MigrationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
The configuration related to the migration to Dataplex Universal Catalog applied to an organization or project. It is the response message for SetConfig and RetrieveEffectiveConfig.
Instance Attribute Summary collapse
-
#catalog_ui_experience ⇒ String
Opt-in status for the UI switch to Dataplex Universal Catalog.
-
#tag_template_migration ⇒ String
Opt-in status for the migration of Tag Templates to Dataplex Universal Catalog.
-
#template_migration_enabled_time ⇒ String
The time when the Tag Template migration was enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1MigrationConfig
constructor
A new instance of GoogleCloudDatacatalogV1MigrationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1MigrationConfig
Returns a new instance of GoogleCloudDatacatalogV1MigrationConfig.
2082 2083 2084 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2082 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog_ui_experience ⇒ String
Opt-in status for the UI switch to Dataplex Universal Catalog.
Corresponds to the JSON property catalogUiExperience
2069 2070 2071 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2069 def catalog_ui_experience @catalog_ui_experience end |
#tag_template_migration ⇒ String
Opt-in status for the migration of Tag Templates to Dataplex Universal Catalog.
Corresponds to the JSON property tagTemplateMigration
2074 2075 2076 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2074 def tag_template_migration @tag_template_migration end |
#template_migration_enabled_time ⇒ String
The time when the Tag Template migration was enabled. If the Tag Template
migration is not enabled, this field is not set.
Corresponds to the JSON property templateMigrationEnabledTime
2080 2081 2082 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2080 def template_migration_enabled_time @template_migration_enabled_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2087 2088 2089 2090 2091 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2087 def update!(**args) @catalog_ui_experience = args[:catalog_ui_experience] if args.key?(:catalog_ui_experience) @tag_template_migration = args[:tag_template_migration] if args.key?(:tag_template_migration) @template_migration_enabled_time = args[:template_migration_enabled_time] if args.key?(:template_migration_enabled_time) end |