Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1OrganizationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1OrganizationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
The configuration related to the migration from Data Catalog to Dataplex Universal Catalog that has been applied to an organization and any projects under it. It is the response message for RetrieveConfig.
Instance Attribute Summary collapse
-
#config ⇒ Hash<String,Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1MigrationConfig>
Map of organizations and project resource names and their configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1OrganizationConfig
constructor
A new instance of GoogleCloudDatacatalogV1OrganizationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1OrganizationConfig
Returns a new instance of GoogleCloudDatacatalogV1OrganizationConfig.
2165 2166 2167 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Hash<String,Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1MigrationConfig>
Map of organizations and project resource names and their configuration. The
format for the map keys is organizations/organizationIdor `projects/`
projectId.
Corresponds to the JSON property config
2163 2164 2165 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2163 def config @config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2170 2171 2172 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2170 def update!(**args) @config = args[:config] if args.key?(:config) end |