Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogResponse
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
Response message for SearchCatalog.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Pagination token that can be used in subsequent calls to retrieve the next page of results.
-
#results ⇒ Array<Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogResult>
Search results.
-
#total_size ⇒ Fixnum
The approximate total number of entries matched by the query.
-
#unreachable ⇒ Array<String>
Unreachable locations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SearchCatalogResponse
constructor
A new instance of GoogleCloudDatacatalogV1SearchCatalogResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SearchCatalogResponse
Returns a new instance of GoogleCloudDatacatalogV1SearchCatalogResponse.
2823 2824 2825 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2823 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Pagination token that can be used in subsequent calls to retrieve the next
page of results.
Corresponds to the JSON property nextPageToken
2803 2804 2805 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2803 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1SearchCatalogResult>
Search results.
Corresponds to the JSON property results
2808 2809 2810 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2808 def results @results end |
#total_size ⇒ Fixnum
The approximate total number of entries matched by the query.
Corresponds to the JSON property totalSize
2813 2814 2815 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2813 def total_size @total_size end |
#unreachable ⇒ Array<String>
Unreachable locations. Search results don't include data from those locations.
To get additional information on an error, repeat the search request and
restrict it to specific locations by setting the SearchCatalogRequest.scope.
restricted_locations parameter.
Corresponds to the JSON property unreachable
2821 2822 2823 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2821 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2828 2829 2830 2831 2832 2833 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 2828 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) @total_size = args[:total_size] if args.key?(:total_size) @unreachable = args[:unreachable] if args.key?(:unreachable) end |