Class: Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1VertexModelSpec
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1VertexModelSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1/classes.rb,
lib/google/apis/datacatalog_v1/representations.rb,
lib/google/apis/datacatalog_v1/representations.rb
Overview
Specification for vertex model resources.
Instance Attribute Summary collapse
-
#container_image_uri ⇒ String
URI of the Docker image to be used as the custom container for serving predictions.
-
#version_aliases ⇒ Array<String>
User provided version aliases so that a model version can be referenced via alias Corresponds to the JSON property
versionAliases. -
#version_description ⇒ String
The description of this version.
-
#version_id ⇒ String
The version ID of the model.
-
#vertex_model_source_info ⇒ Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1VertexModelSourceInfo
Detail description of the source information of a Vertex model.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1VertexModelSpec
constructor
A new instance of GoogleCloudDatacatalogV1VertexModelSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1VertexModelSpec
Returns a new instance of GoogleCloudDatacatalogV1VertexModelSpec.
3905 3906 3907 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3905 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_image_uri ⇒ String
URI of the Docker image to be used as the custom container for serving
predictions.
Corresponds to the JSON property containerImageUri
3882 3883 3884 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3882 def container_image_uri @container_image_uri end |
#version_aliases ⇒ Array<String>
User provided version aliases so that a model version can be referenced via
alias
Corresponds to the JSON property versionAliases
3888 3889 3890 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3888 def version_aliases @version_aliases end |
#version_description ⇒ String
The description of this version.
Corresponds to the JSON property versionDescription
3893 3894 3895 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3893 def version_description @version_description end |
#version_id ⇒ String
The version ID of the model.
Corresponds to the JSON property versionId
3898 3899 3900 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3898 def version_id @version_id end |
#vertex_model_source_info ⇒ Google::Apis::DatacatalogV1::GoogleCloudDatacatalogV1VertexModelSourceInfo
Detail description of the source information of a Vertex model.
Corresponds to the JSON property vertexModelSourceInfo
3903 3904 3905 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3903 def vertex_model_source_info @vertex_model_source_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3910 3911 3912 3913 3914 3915 3916 |
# File 'lib/google/apis/datacatalog_v1/classes.rb', line 3910 def update!(**args) @container_image_uri = args[:container_image_uri] if args.key?(:container_image_uri) @version_aliases = args[:version_aliases] if args.key?(:version_aliases) @version_description = args[:version_description] if args.key?(:version_description) @version_id = args[:version_id] if args.key?(:version_id) @vertex_model_source_info = args[:vertex_model_source_info] if args.key?(:vertex_model_source_info) end |